@@ -36,7 +36,7 @@ class Versioner:
 
 
 class BaseRun:
-    client = APIClient(base_url="unix://var/run/docker.sock")
+    client = APIClient(base_url=os.getenv("DOCKER_HOST", "unix://var/run/docker.sock"))
     config = configparser.ConfigParser()
 
     def __init__(self, args) -> None:
@@ -105,7 +105,7 @@ class DockerRun(BaseRun):
         result = self.client.push(repo_tag, stream=True, decode=True)
         for line in result:
             logger.info(
-                line.get("status", ""), line.get("progress", ""), line.get("id", "")
+                f"{line.get('status', '-')} {line.get('progress', '-')}  {line.get('id', '-')}"
             )
 
     def __call__(self) -> None:
